@@ -1,4 +1,4 @@
-# $Id: Get_nice.pm,v 1.9 2004/03/30 19:41:11 epaepa Exp $
+# $Id: Get_nice.pm,v 1.12 2004/11/16 18:29:59 mattiasholmlund Exp $
 #
 # Library to wrap LWP::Simple to put in a random delay between
 # requests and to set User-Agent.  We really should be using
@@ -20,6 +20,8 @@
 # pages is the only use of it.
 #
 
+use strict;
+
 package XMLTV::Get_nice;
 use base 'Exporter';
 our @EXPORT = qw(get_nice);
@@ -30,6 +32,8 @@ our $Delay = 5; # in seconds
 
 our $get = \&LWP::Simple::get;
 
+init_cache();
+
 sub get_nice( $ ) {
     # This is to ensure scalar context, to work around weirdnesses
     # with Memoize (I just can't figure out how SCALAR_CACHE and
@@ -71,4 +75,64 @@ sub get_nice_aux( $ ) {
     $last_get_time = time();
     return $r;
 }
+
+# Initialize HTTP::Cache::Transparent if the file
+# specified by the environment variable CACHE_CONF 
+# (default ~/.xmltv/cache.conf) exists.
+sub init_cache
+{
+    my $home = $ENV{HOME} || 
+               $ENV{HOMEDRIVE} . $ENV{HOMEPATH} ||
+               ".";
+
+    my $conffile = $ENV{CACHE_CONF} || "$home/.xmltv/cache.conf"; 
+    
+    if (not -f($conffile)) {
+        # The configuration file doesn't exist. Don't use the cache.
+        # In the future, we may want to create a default configuration
+        # file here.
+        return;
+    }
+
+    open(IN, "< $conffile") 
+        or die "Failed to read from $conffile";
+  
+    my %data;
+    my $line;
+    
+    while ($line = <IN>) {
+        next if $line =~ /^\s*#/;
+        next if $line =~ /^\s*$/;
+        $line =~ tr/\n\r//d;
+
+        my($key, $value) = split(/\s+/, $line, 2);
+        if (index(" BasePath Verbose ", " $key ") == -1) {
+            print STDERR "Unknown configuration key $key in $conffile.\n";
+            close(IN);
+            exit 1;
+        }
+
+        $data{$key} = $value;
+    }
+
+    close(IN);
+
+    if (exists($data{DisableCache}) and $data{DisableCache}) {
+        return;
+    }
+
+    delete($data{DisableCache});
+
+    if (not defined($data{BasePath})) {
+        print STDERR "No BasePath specified in $conffile.\n";
+        exit 1;
+    }
+
+    (-d $data{BasePath}) or mkdir($data{BasePath}, 0777)
+      or die "cannot mkdir $data{BasePath}: $!";
+
+    require HTTP::Cache::Transparent;
+    HTTP::Cache::Transparent::init(\%data);
+}
+
 1;
