@@ -1,5 +1,5 @@
 #
-# $Id: IMDB.pm,v 1.44 2004/01/20 20:06:15 epaepa Exp $
+# $Id: IMDB.pm,v 1.47 2004/09/05 21:35:31 jveldhuis Exp $
 #
 # The IMDB file contains two packages:
 # 1. XMLTV::IMDB::Cruncher package which parses and manages IMDB "lists" files
@@ -890,7 +890,7 @@ sub applyFound($$$)
 		my $name=$idInfo->{title};
 		my $found=0;
 		for my $v (@{$prog->{title}}) {
-		    if ( $v->[0]=~m/^$name$/i ) {
+		    if ( lc($v->[0]) eq lc($name) ) {
 			$found=1;
 		    }
 		    else {
@@ -971,7 +971,7 @@ sub applyFound($$$)
 		    for my $name (@{$prog->{credits}->{director}}) {
 			my $found=0;
 			for(@list) {
-			    if ( m/^$name$/i ) {
+			    if ( lc eq lc($name) ) {
 				$found=1;
 			    }
 			}
@@ -1005,7 +1005,7 @@ sub applyFound($$$)
 		for my $name (@{$prog->{credits}->{actor}}) {
 		    my $found=0;
 		    for(@list) {
-			if ( m/^$name$/i ) {
+			if ( lc eq lc($name) ) {
 			    $found=1;
 			}
 		    }
@@ -1077,7 +1077,7 @@ sub applyFound($$$)
 		my $found=0;
 		#print "checking category $value->[0] with $mycategory\n";
 		for my $c (@categories) {
-		    if ( $c->[0]=~m/^$value->[0]$/i ) {
+		    if ( lc($c->[0]) eq lc($value->[0]) ) {
 			$found=1;
 		    }
 		}
@@ -1830,7 +1830,7 @@ sub invokeStage($$)
     my $startTime=time();
     if ( $stage == 1 ) {
 	$self->status("parsing Movies list for stage $stage..");
-	my $countEstimate=385000;
+	my $countEstimate=398000;
 	my $num=$self->readMoviesOrGenres("Movies", $countEstimate, "$self->{imdbListFiles}->{movies}");
 	if ( $num < 0 ) {
 	    if ( $num == -2 ) {
@@ -1881,7 +1881,7 @@ sub invokeStage($$)
     elsif ( $stage == 2 ) {
 	$self->status("parsing Directors list for stage $stage..");
 
-	my $countEstimate=81000;
+	my $countEstimate=85000;
 	my $num=$self->readCastOrDirectors("Directors", $countEstimate, "$self->{imdbListFiles}->{directors}");
 	if ( $num < 0 ) {
 	    if ( $num == -2 ) {
@@ -1948,7 +1948,7 @@ sub invokeStage($$)
 	$self->status("parsing Actors list for stage $stage..");
 
 	#print "re-reading movies into memory for reverse lookup..\n";
-	my $countEstimate=490000;
+	my $countEstimate=508000;
 	my $num=$self->readCastOrDirectors("Actors", $countEstimate, "$self->{imdbListFiles}->{actors}");
 	if ( $num < 0 ) {
 	    if ( $num == -2 ) {
@@ -1999,7 +1999,7 @@ sub invokeStage($$)
     elsif ( $stage == 4 ) {
 	$self->status("parsing Actresses list for stage $stage..");
 
-	my $countEstimate=295000;
+	my $countEstimate=308000;
 	my $num=$self->readCastOrDirectors("Actresses", $countEstimate, "$self->{imdbListFiles}->{actresses}");
 	if ( $num < 0 ) {
 	    if ( $num == -2 ) {
@@ -2049,7 +2049,7 @@ sub invokeStage($$)
     }
     elsif ( $stage == 5 ) {
 	$self->status("parsing Genres list for stage $stage..");
-	my $countEstimate=255000;
+	my $countEstimate=290000;
 	my $num=$self->readMoviesOrGenres("Genres", $countEstimate, "$self->{imdbListFiles}->{genres}");
 	if ( $num < 0 ) {
 	    if ( $num == -2 ) {
@@ -2099,7 +2099,7 @@ sub invokeStage($$)
     }
     elsif ( $stage == 6 ) {
 	$self->status("parsing Ratings list for stage $stage..");
-	my $countEstimate=80000;
+	my $countEstimate=90000;
 	my $num=$self->readRatings($countEstimate, "$self->{imdbListFiles}->{ratings}");
 	if ( $num < 0 ) {
 	    if ( $num == -2 ) {
@@ -2712,8 +2712,8 @@ sub crunchStage($$)
 	}
 	else {
 	    $self->status("prep stage $stage succeeded with $self->{errorCountInLog} errors in $self->{imdbDir}/stage$stage.log");
-	    if ( $stage == 7 && $self->{errorCountInLog} > 30 && $self->{errorCountInLog} < 50 ) {
-		$self->status("this stage commonly produces around 44 (or so) warnings because of imdb");
+	    if ( $stage == 7 && $self->{errorCountInLog} > 30 && $self->{errorCountInLog} < 80 ) {
+		$self->status("this stage commonly produces around 60 (or so) warnings because of imdb");
 		$self->status("list file inconsistancies, they can usually be safely ignored");
 	    }
 	}
