@@ -1,6 +1,6 @@
 #!perl -w
 #
-# $Id: exe_wrap.pl,v 1.46 2004/05/23 19:18:13 epaepa Exp $
+# $Id: exe_wrap.pl,v 1.53 2004/11/29 08:01:00 rmeden Exp $
 # This is a quick XMLTV shell routing to use with the windows exe
 #
 # A single EXE is needed to allow sharing of modules and dlls of all the
@@ -20,23 +20,32 @@ use Carp;
 
 $Carp::MaxEvalLen=40; # limit confess output
 
-# Check for error of running from 'Run' dialogue box with redirection,
-# which Run doesn't understand,
 #
-if (grep /[<>|]/, @ARGV) {
-    warn <<END
-The command line:
+# this check should not be done, at least not this way. it prevents some regular expressions!
+#
+## Check for error of running from 'Run' dialogue box with redirection,
+## which Run doesn't understand,
+##
+#if (grep /[<>|]/, @ARGV) {
+#    warn <<END
+#The command line:
+#
+#$0 @ARGV
+#
+#contains redirections, so should be run from a command prompt window.
+#In general, it's a good idea to always run xmltv from a command prompt
+#so that you can see any errors and warnings produced.
+#END
+#      ;
+#    sleep 10;
+#    exit 1;
+#}
 
-$0 @ARGV
-
-contains redirections, so should be run from a command prompt window.
-In general, it's a good idea to always run xmltv from a command prompt
-so that you can see any errors and warnings produced.
-END
-      ;
-    sleep 10;
-    exit 1;
-}
+#
+# check for --quiet
+#
+my $opt_quiet=0;
+foreach (@ARGV) {$opt_quiet = 1 if /--quiet/i };
 
 #
 # get/check time zone
@@ -54,13 +63,13 @@ unless (exists $ENV{TZ})
        $ENV{TZ}= $tz;
 
 } #timezone
-print STDERR "Timezone is $ENV{TZ}\n";
+print STDERR "Timezone is $ENV{TZ}\n" unless $opt_quiet;
 
 
 $cmd = shift || "";
 
 # --version (and abbreviations thereof)
-my $VERSION = '0.5.34';
+my $VERSION = '0.5.37';
 if (index('--version', $cmd) == 0 and length $cmd >= 3) {
     print "xmltv $VERSION\n";
     exit;
@@ -82,6 +91,7 @@ END
 # some programs use a "share" directory
 #
 if ($cmd eq 'tv_grab_uk_rt'
+ or $cmd eq 'tv_grab_uk_bleb'
  or $cmd eq 'tv_grab_it'
  or $cmd eq 'tv_grab_nl'
  or $cmd eq 'tv_grab_na_dd',
@@ -99,7 +109,7 @@ if ($cmd eq 'tv_grab_uk_rt'
     	    {
 	        die "directory $dir not found\n If not kept with the executable, specify with --share\n"
 	        }
-        print STDERR "adding '--share=$dir'\n";
+        print STDERR "adding '--share=$dir'\n" unless $opt_quiet;
         push @ARGV,"--share",$dir;
     }
 }
@@ -123,6 +133,7 @@ foreach my $exe (split(/ /,$files))
     $0 = $_;        # set $0 to our script
     do $exe;
     print STDERR $@ if length($@);
+    exit 1 if length($@);
     exit 0;
 }
 
